const path = require('path');
const process = require('process');

const babel = require('rollup-plugin-babel');
const commonjs = require('rollup-plugin-commonjs');
const resolve = require('rollup-plugin-node-resolve');
const replace = require('rollup-plugin-replace');
const style = require('@coderesque/rollup-plugin-style').default;
const { terser } = require('rollup-plugin-terser');


const env = process.env.NODE_ENV || 'development';
const isProductionEnv = env === 'production';

const pkg = require(path.join(process.cwd(), 'package.json'));
const dependencies = Object.keys(pkg.peerDependencies || {});

module.exports = {
    input: 'src/index.ts',
    output: {
        file: isProductionEnv
            ? 'dist/index.production.min.js'
            : 'dist/index.development.js',
        format: 'esm',
    },
    external: function external(resolveId) {
        if (resolveId.startsWith('@babel/runtime')) {
            return true;
        }

        return dependencies.includes(resolveId);
    },
    plugins: [
        style(),
        resolve({
            extensions: [
                '.js',
                '.jsx',
                '.ts',
                '.tsx',
            ],
        }),
        replace({
            'process.env.NODE_ENV': JSON.stringify(env),
        }),
        // this setup assumes that there is a `babel.config.js` in the project root.
        babel({
            extensions: [
                '.js',
                '.jsx',
                '.ts',
                '.tsx',
            ],
            runtimeHelpers: true,
        }),
        commonjs(),
        isProductionEnv && terser(),
    ].filter(Boolean),
};
